summaryrefslogtreecommitdiffstats
path: root/kpilot/kpilot/listCat.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/kpilot/listCat.h')
-rw-r--r--kpilot/kpilot/listCat.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/kpilot/kpilot/listCat.h b/kpilot/kpilot/listCat.h
index fd53413b..e2063303 100644
--- a/kpilot/kpilot/listCat.h
+++ b/kpilot/kpilot/listCat.h
@@ -51,8 +51,8 @@ class QStringList;
* ListCategorizer *lc = new ListCategorizer(this,colors);
* lc->setColumnText(0,i18n("Color"));
* lc->setColumnText(1,i18n("HTML"));
- * QListViewItem *stdKDE = lc->addCategory(i18n("Standard KDE"));
- * (void) new QListViewItem(stdKDE,i18n("red"),"#FF0000");
+ * TQListViewItem *stdKDE = lc->addCategory(i18n("Standard KDE"));
+ * (void) new TQListViewItem(stdKDE,i18n("red"),"#FF0000");
* @endcode
* to set sensible column headers for a list of colors
* and their HTML equivalents (although why you would want
@@ -73,7 +73,7 @@ public:
* startOpen set to false. The parameters
* @p parent and @p name are the usual Qt ones.
*/
- ListCategorizer(QWidget *parent,
+ ListCategorizer(TQWidget *parent,
const char *name = 0);
/**
* Constructor.
@@ -82,9 +82,9 @@ public:
* already inserted. In addition, this constructor lets you
* specify whether or not startOpen is set.
*/
- ListCategorizer(const QStringList& categories,
+ ListCategorizer(const TQStringList& categories,
bool startOpen,
- QWidget *parent,
+ TQWidget *parent,
const char *name = 0);
/**
@@ -92,7 +92,7 @@ public:
* All the categories are added without descriptions;
* use addCategory on a per-category basis for that.
*/
- void addCategories(const QStringList&);
+ void addCategories(const TQStringList&);
/**
* Add a category with name @p name and optional
* @p description. This can be useful if you want
@@ -100,15 +100,15 @@ public:
* refer to this category in the future without
* using findCategory().
*
* @return the QListViewItem created for the category
*/
- QListViewItem *addCategory(const QString& name,
- const QString& description = QString::null);
+ TQListViewItem *addCategory(const TQString& name,
+ const TQString& description = TQString::null);
/**
* Returns the list of names of the categories in
* the ListCategorizer.
*/
- QStringList categories() const
+ TQStringList categories() const
{
return listSiblings(firstChild());
} ;
@@ -121,18 +121,18 @@ public:
* constructor. That way you can also hide more data in
* the remaining columns.
*/
- QListViewItem *addItem(const QString& category,
- const QString& name,
- const QString& description = QString::null);
+ TQListViewItem *addItem(const TQString& category,
+ const TQString& name,
+ const TQString& description = TQString::null);
/**
* Returns the list of strings in column @p column under
* category @p category. You can do this to get, for example
* the names of all the items categorized under a given
* category, or, more usefully, set @p column to something
* other that 0 (name) or 1 (description) to return the
* QStringList hidden in the non-visible columns.
*/
- QStringList items(const QString& category,int column=0) const
+ TQStringList items(const TQString& category,int column=0) const
{
return listSiblings(findCategory(category),column);
}
@@ -143,18 +143,18 @@ public:
* since just remembering the pointer addCategory gives
* you is faster and uses hardly any memory.
*/
- QListViewItem *findCategory(const QString& categoryName) const;
+ TQListViewItem *findCategory(const TQString& categoryName) const;
/**
* Return the list of strings in column @p column of all siblings
* of the given item @p p. If you remembered a pointer to a
* category, you can use
* @code
- * QStringList l = lc->listSiblings(stdKDE->firstChild(),2);
+ * TQStringList l = lc->listSiblings(stdKDE->firstChild(),2);
* @endcode
* to get the list of strings in hidden column 2 under
* the category you remembered.
*/
- QStringList listSiblings(const QListViewItem *p,int column=0) const;
+ TQStringList listSiblings(const TQListViewItem *p,int column=0) const;
/**
* @return whether new categories are inserted in an
@@ -174,7 +174,7 @@ protected:
/**
* Reimplemented to prevent categories from being dragged.
*/
- virtual bool acceptDrag (QDropEvent* event) const;
+ virtual bool acceptDrag (TQDropEvent* event) const;
/**
* Reimplemented to prevent categories from being dragged.
*/
@@ -182,7 +182,7 @@ protected:
/**
* Reimplemented to prevent categories from being dragged.
*/
- virtual void contentsDropEvent (QDropEvent*);
+ virtual void contentsDropEvent (TQDropEvent*);
@@ -200,13 +200,13 @@ private:
class RichListViewItem : public QListViewItem
{
public:
- RichListViewItem(QListViewItem *parent,
- QString,
+ RichListViewItem(TQListViewItem *parent,
+ TQString,
int);
virtual ~RichListViewItem();
- virtual void paintCell(QPainter *,
- const QColorGroup &,
+ virtual void paintCell(TQPainter *,
+ const TQColorGroup &,
int column,
int width,
int alignment);
@@ -221,7 +221,7 @@ protected:
protected:
bool *fIsRich;
- QRect *fRect;
+ TQRect *fRect;
int fColumns;
} ;
@@ -100,15 +100,15 @@ public:
* using findCategory().
*
- * @return the QListViewItem created for the category
+ * @return the TQListViewItem created for the category
*/
@@ -121,18 +121,18 @@ public:
* category, or, more usefully, set @p column to something
* other that 0 (name) or 1 (description) to return the
- * QStringList hidden in the non-visible columns.
+ * TQStringList hidden in the non-visible columns.
*/